@@ -2,8 +2,8 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.pool import Pool
-from . import work
-from . import purchase
+
+from . import purchase, work
 
 
 def register():
@@ -11,6 +11,6 @@ def register():
         work.Work,
         module='project_revenue', type_='model')
     Pool.register(
-        purchase.PurchaseLine,
+        purchase.Line,
         module='project_revenue', type_='model',
         depends=['purchase'])
